// Project: Rocket Commander, File: Credits.cs
// Namespace: RocketCommander.GameScreens, Class: Credits
// Path: C:\code\Rocket Commander\GameScreens, Author: Abi
// Code lines: 46, Size of file: 857 Bytes
// Creation date: 23.11.2005 18:37
// Last modified: 12.12.2005 05:30
// Generated with Commenter by abi.exDream.com

#region Using directives
using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using RocketCommander.Graphics;
using Font = RocketCommander.Graphics.Font;
using RocketCommander.Game;
using RocketCommander.Properties;
using System.Diagnostics;
using System.Threading;
#endregion

namespace RocketCommander.GameScreens
{
	/// <summary>
	/// Credits
	/// </summary>
	class Credits : IGameScreen
	{
		#region Variables
		/// <summary>
		/// Fonts for credits
		/// </summary>
		private Font smallFont = null, mediumFont = null, bigFont = null;
		#endregion

		#region Properties
		/// <summary>
		/// Name of this game screen
		/// </summary>
		/// <returns>String</returns>
		public string Name
		{
			get
			{
				return "Credits";
			} // get
		} // Name

		private bool quit = false;
		/// <summary>
		/// Returns true if we want to quit this screen and return to the
		/// previous screen. If no more screens are left the game is exited.
		/// </summary>
		/// <returns>Bool</returns>
		public bool Quit
		{
			get
			{
				return quit;
			} // get
		} // Quit
		#endregion

		#region Constructor
		/// <summary>
		/// Create credits
		/// </summary>
		public Credits()
		{
			smallFont = new Font("Arial", 11);
			mediumFont = new Font("Verdana", 21);
			bigFont = new Font("Verdana", 28);
		} // Credits()
		#endregion

		#region Write credits
		/// <summary>
		/// Write credits
		/// </summary>
		/// <param name="xPos">X coordinate</param>
		/// <param name="yPos">Y coordinate</param>
		/// <param name="leftText">Left text</param>
		/// <param name="rightText">Right text</param>
		private void WriteCredits(int xPos, int yPos,
			string leftText, string rightText)
		{
			mediumFont.WriteText(xPos, yPos, leftText);
			smallFont.WriteText(xPos + 400, yPos + 8, rightText);
		} // WriteCredits(xPos, yPos, leftText)

		/// <summary>
		/// Write credits with link
		/// </summary>
		/// <param name="xPos">X coordinate</param>
		/// <param name="yPos">Y coordinate</param>
		/// <param name="leftText">Left text</param>
		/// <param name="rightText">Right text</param>
		/// <param name="linkText">Link text</param>
		private void WriteCreditsWithLink(int xPos, int yPos, string leftText,
			string rightText, string linkText, RocketCommanderForm form)
		{
			WriteCredits(xPos, yPos, leftText, rightText);

			// Process link (put below rightText)
			bool overLink = form.MouseInBox(new Rectangle(
				xPos + 400, yPos + 8 + smallFont.Height, 200, smallFont.Height));
			smallFont.WriteText(xPos + 400, yPos + 8 + smallFont.Height, linkText,
				overLink ? Color.Red : Color.White);
			if (overLink &&
				GameForm.Mouse.LeftButtonPressed &&
				form.wasMouseButtonPressedLastFrame == false)
			{
				Process.Start(linkText);
				Thread.Sleep(100);
			} // if
		} // WriteCreditsWithLink(xPos, yPos, leftText)
		#endregion

		#region Run
		/// <summary>
		/// Run game screen. Called each frame.
		/// </summary>
		/// <param name="form">Form for access to asteroid manager and co</param>
		public void Run(RocketCommanderForm form)
		{
			// Render background
			form.RenderMenuBackground();

			// Credits
			int xPos = 100 * GraphicForm.Resolution.Width / 1024;
			int yPos = 170 * GraphicForm.Resolution.Height / 768;
			bigFont.WriteText(xPos, yPos, Texts.Credits);

			WriteCreditsWithLink(xPos, yPos+72, "Idea, Design, Programming",
				"Benjamin Nitschke (abi)",
				"http://abi.exdream.com", form);
			WriteCredits(xPos, yPos + 142, "3D Modeling, Sky",
				"Christoph Riencker (dr.waii)");
			WriteCredits(xPos, yPos + 202, "Screen Design",
				"Leif Griga");
			WriteCredits(xPos, yPos + 262, "Music, Sounds",
				"Boje Holtz");
			WriteCredits(xPos, yPos + 327, "Thanks fly out to",
				"Enrico Cieslik (Judge), Manuel Nitschke (www.netfreak.de)\n"+
				"Frederic Schneider (www.gameports.net), Daniel Kre (ViperDK)\n"+
				"ZMan (www.thezbuffer.com) and DonD (AW boards) for testing.\n"+
				"Microsoft for supporting this game, especially to Dirk Primbs\nand " +
				"Lars Lippert. .NET 2.0 and Managed DirectX are also very great.");

			smallFont.WriteText(xPos, 667 * GraphicForm.Resolution.Height / 768,
				"Dedicated to all lonely asteroids in space. "+
				"And everyone that feels that way.");

			if (form.RenderMenuButton(MenuButton.Back,
				new Point(1024 - 210, 768 - 150)) ||
				GameForm.Keyboard.EscapeJustPressed)
			{
				quit = true;
			} // if
		} // Run(form)
		#endregion
	} // class Credits
} // namespace RocketCommander.GameScreens
