// Project: Rocket Commander, File: MainMenu.cs
// Namespace: RocketCommander.GameScreens, Class: MainMenu
// Path: C:\code\Rocket Commander\GameScreens, Author: Abi
// Code lines: 17, Size of file: 1506 Bytes
// Creation date: 01.11.2005 23:55
// Last modified: 11.03.2006 03:08
// Generated with Commenter by abi.exDream.com

#region Using directives
using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using System.Collections;
using RocketCommander.Helpers;
using Microsoft.DirectX.DirectInput;
using Microsoft.DirectX;
using RocketCommander.Game;
using Font = RocketCommander.Graphics.Font;
using RocketCommander.Graphics;
using RocketCommander.Properties;
using System.Windows.Forms;
#endregion

namespace RocketCommander.GameScreens
{
	/// <summary>
	/// Main menu
	/// </summary>
	class MainMenu : IGameScreen
	{
		#region Variables
		/// <summary>
		/// Font for music on/off
		/// </summary>
		private Font smallFont = null;
		#endregion

		#region Properties
		/// <summary>
		/// Name of this game screen
		/// </summary>
		/// <returns>String</returns>
		public string Name
		{
			get
			{
				return "Main menu";
			} // get
		} // Name

		private bool quit = false;
		/// <summary>
		/// Returns true if we want to quit this screen and return to the
		/// previous screen. If no more screens are left the game is exited.
		/// </summary>
		/// <returns>Bool</returns>
		public bool Quit
		{
			get
			{
				return quit;
			} // get
		} // Quit

		/// <summary>
		/// Reset camera when starting.
		/// </summary>
		public bool resetCamera = true;
		#endregion

		#region Constructor
		/// <summary>
		/// Create main menu
		/// </summary>
		public MainMenu()
		{
			smallFont = new Font("Arial", 10);
		} // MainMenu()
		#endregion

		#region Run
		Point[] buttonLocations = new Point[]
			{
				new Point(202, 181),
				new Point(161, 266),
				new Point(137, 351),
				new Point(136, 436),
				new Point(150, 521),
				new Point(186, 606),
			};
		/// <summary>
		/// Input selection for xbox controller. Initially not set.
		/// Press up/down joystick for changing.
		/// </summary>
		int xInputMenuSelection = -1;
		/// <summary>
		/// Select menu item for XInput
		/// </summary>
		void SelectMenuItemForXInput()
		{
			if (xInputMenuSelection >= 0 &&
				xInputMenuSelection < buttonLocations.Length)
				Cursor.Position = new Point(
					(buttonLocations[xInputMenuSelection].X + 100) *
					GraphicForm.Resolution.Width / 1024,
					(buttonLocations[xInputMenuSelection].Y + 38) *
					GraphicForm.Resolution.Height / 768);
		} // SelectMenuItemForXInput()

		/// <summary>
		/// Run game screen. Called each frame.
		/// </summary>
		/// <param name="form">Form for access to asteroid manager and co</param>
		public void Run(RocketCommanderForm form)
		{
			if (resetCamera)
			{
				resetCamera = false;
				form.camera.SetPosition(Vector3.Empty);
				form.camera.InGame = false;
			} // if

			// Render background
			form.RenderMenuBackground();

			// Show all buttons
			int buttonNum = 0;
			foreach (MenuButton button in
				EnumHelper.GetEnumerator(typeof(MenuButton)))
				// Don't render the back button
				if (button != MenuButton.Back)
				{
					if (form.RenderMenuButton(button, buttonLocations[buttonNum]))
					{
						if (button == MenuButton.Missions)
							form.AddGameScreen(new MissionSelection());
						else if (button == MenuButton.Highscore)
							form.AddGameScreen(new Highscores());
						else if (button == MenuButton.Credits)
							form.AddGameScreen(new Credits());
						else if (button == MenuButton.Options)
							form.AddGameScreen(new Options());
						else if (button == MenuButton.Help)
							form.AddGameScreen(new Help());
						else if (button == MenuButton.Exit)
							quit = true;
					} // if
					buttonNum++;
					if (buttonNum >= buttonLocations.Length)
						break;
				} // if

			// Hotkeys, M=Mission, H=Highscores, C=Credits, Esc=Quit
			if (GameForm.Keyboard.State[Key.M])
				form.AddGameScreen(new MissionSelection());
			else if (GameForm.Keyboard.State[Key.H])
				form.AddGameScreen(new Highscores());
			else if (GameForm.Keyboard.State[Key.C])
				form.AddGameScreen(new Credits());
			else if (GameForm.Keyboard.State[Key.O])
				form.AddGameScreen(new Options());
			else if (GameForm.Keyboard.State[Key.F1])
				form.AddGameScreen(new Help());
			else if (GameForm.Keyboard.EscapeJustPressed)
				quit = true;

			// If pressing XBox controller up/down change selection
			if (XInput.Joystick == XInput.JoystickDir.Down &&
				XInput.JoystickLastFrame != XInput.JoystickDir.Down)
			{
				xInputMenuSelection =
					(xInputMenuSelection + 1) % buttonLocations.Length;
				SelectMenuItemForXInput();
			} // if (XInput.Joystick)
			else if (XInput.Joystick == XInput.JoystickDir.Up &&
				XInput.JoystickLastFrame != XInput.JoystickDir.Up)
			{
				if (xInputMenuSelection <= 0)
					xInputMenuSelection = buttonLocations.Length;
				xInputMenuSelection--;
				SelectMenuItemForXInput();
			} // if (XInput.Joystick)

			string versionText = "v" +
				//obs: Application.ProductVersion.Substring(0, 3);
				Program.versionHigh + "." + Program.versionLow;
			smallFont.WriteText(
				GraphicForm.Resolution.Width -
				versionText.Length * smallFont.Height / 2 + 4,
				GraphicForm.Resolution.Height - smallFont.Height - 1,
				versionText,
				Color.Gray);
		} // Run(form)
		#endregion
	} // class MainMenu
} // namespace RocketCommander.GameScreens
