// Project: Rocket Commander, File: MissionSelection.cs
// Namespace: RocketCommander.GameScreens, Class: MissionSelection
// Path: C:\code\Rocket Commander\GameScreens, Author: Abi
// Code lines: 225, Size of file: 7,66 KB
// Creation date: 11.12.2005 18:08
// Last modified: 12.12.2005 01:34
// Generated with Commenter by abi.exDream.com

#region Using directives
using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using RocketCommander.Graphics;
using RocketCommander.Game;
using Font = RocketCommander.Graphics.Font;
using RocketCommander.Properties;
using RocketCommander.Helpers;
using System.Windows.Forms;
#endregion

namespace RocketCommander.GameScreens
{
	/// <summary>
	/// Mission selection
	/// </summary>
	class MissionSelection : IGameScreen
	{
		#region Variables
		/// <summary>
		/// Fonts for mission selection
		/// </summary>
		private Font mediumFont = null, bigFont = null;
		#endregion

		#region Properties
		/// <summary>
		/// Name of this game screen
		/// </summary>
		/// <returns>String</returns>
		public string Name
		{
			get
			{
				return "Mission selection";
			} // get
		} // Name

		private bool quit = false;
		/// <summary>
		/// Returns true if we want to quit this screen and return to the
		/// previous screen. If no more screens are left the game is exited.
		/// </summary>
		/// <returns>Bool</returns>
		public bool Quit
		{
			get
			{
				return quit;
			} // get
		} // Quit
		#endregion

		#region Constructor
		/// <summary>
		/// Create MissionSelection
		/// </summary>
		public MissionSelection()
		{
			mediumFont = new Font("Verdana", 16);
			bigFont = new Font("Verdana", 24);
		} // MissionSelection()
		#endregion

		#region Run
		/// <summary>
		/// Input selection for xbox controller. Initially not set.
		/// Press left/right joystick for changing.
		/// </summary>
		int xInputLevelSelection = -1;
		/// <summary>
		/// Select menu item for XInput
		/// </summary>
		void SelectLevelForXInput(int maxLevels)
		{
			if (xInputLevelSelection >= 0 &&
				xInputLevelSelection < maxLevels)
				Cursor.Position = new Point(
					(50 + 20) * GraphicForm.Resolution.Width / 1024 +
					xInputLevelSelection * (GraphicForm.Resolution.Width - 175) / 4,
					(220 + 50) * GraphicForm.Resolution.Height / 768);
		} // SelectMenuItemForXInput()

		/// <summary>
		/// Run game screen. Called each frame.
		/// </summary>
		/// <param name="form">Form for access to asteroid manager and co</param>
		public void Run(RocketCommanderForm form)
		{
			// Render background
			form.RenderMenuBackground();

			// Select mission
			int xPos = 50 * GraphicForm.Resolution.Width / 1024;
			int yPos = 168 * GraphicForm.Resolution.Height / 768;
			bigFont.WriteText(xPos, yPos, Texts.SelectMission);

			if (form.RenderMenuButton(MenuButton.Back,
				new Point(1024 - 210, 768 - 150)) ||
				GameForm.Keyboard.EscapeJustPressed)
			{
				quit = true;
			} // if

			// If pressing XBox controller up/down change selection
			int maxLevels = Math.Min(form.levels.Length, 4);
			if (XInput.Joystick == XInput.JoystickDir.Right &&
				XInput.JoystickLastFrame != XInput.JoystickDir.Right)
			{
				xInputLevelSelection =
					(xInputLevelSelection + 1) % maxLevels;
				SelectLevelForXInput(maxLevels);
			} // if (XInput.Joystick)
			else if (XInput.Joystick == XInput.JoystickDir.Left &&
				XInput.JoystickLastFrame != XInput.JoystickDir.Left)
			{
				if (xInputLevelSelection <= 0)
					xInputLevelSelection = maxLevels;
				xInputLevelSelection--;
				SelectLevelForXInput(maxLevels);
			} // if (XInput.Joystick)

			// Show all levels (max. 4 levels are supported right now)
			for (int num = 0; num < form.levels.Length &&
				num < 4; num++)
			{
				Level level = form.levels[num];
				xPos = 50 * GraphicForm.Resolution.Width / 1024 +
					num * (GraphicForm.Resolution.Width - 175) / 4;
				yPos = 220 * GraphicForm.Resolution.Height / 768;

				// Is selected?
				int maxHeight = GraphicForm.Resolution.Height * 6 / 7 - yPos;
				int height = Math.Min(level.Length, maxHeight);
				Rectangle clickArea = new Rectangle(
					xPos, yPos,
					(GraphicForm.Resolution.Width - 150) / 4 - 10, height + 27);
				Color col = form.MouseInBox(clickArea) && quit == false ?
					Color.Red : Color.White;

				// Write name on top
				mediumFont.WriteText(xPos, yPos, level.Name, col);

				// Calc preview rect
				Rectangle previewRect = new Rectangle(
					xPos, yPos + 26, 40, height);

				// Disable linear filtering for level textures
				GraphicForm.DisableLinearTextureFiltering();

				// Show level preview.
				// Show 2 parts if bigger than 512
				if (level.Length > 512)
				{
					previewRect = new Rectangle(
						xPos + 70, yPos + 26, 40, height);
					level.Texture.RenderOnScreen(previewRect,
						new Rectangle(0, 0, 40, Math.Min(level.Length, 512)));

					// Draw lines around preview rect to mark highlighting
					Point upperLeft = new Point(previewRect.X, previewRect.Y);
					Point upperRight = new Point(previewRect.Right, previewRect.Y);
					Point lowerLeft = new Point(previewRect.X, previewRect.Bottom);
					Point lowerRight = new Point(previewRect.Right, previewRect.Bottom);
					GraphicForm.LineManager.AddLine(upperLeft, upperRight, col);
					GraphicForm.LineManager.AddLine(upperLeft, lowerLeft, col);
					GraphicForm.LineManager.AddLineWithShadow(upperRight, lowerRight,
						col);
					GraphicForm.LineManager.AddLineWithShadow(lowerLeft,
						new Point(lowerRight.X + 1, lowerRight.Y), col);

					previewRect = new Rectangle(
						xPos, yPos + 26 + 8, 40, height);
					level.Texture.RenderOnScreen(previewRect,
						new Rectangle(0, 512, 40, Math.Min(level.Length - 512, 512)));

					upperLeft = new Point(previewRect.X, previewRect.Y);
					upperRight = new Point(previewRect.Right, previewRect.Y);
					lowerLeft = new Point(previewRect.X, previewRect.Bottom);
					lowerRight = new Point(previewRect.Right, previewRect.Bottom);
					GraphicForm.LineManager.AddLine(upperLeft, upperRight, col);
					GraphicForm.LineManager.AddLine(upperLeft, lowerLeft, col);
					GraphicForm.LineManager.AddLineWithShadow(upperRight, lowerRight,
						col);
					GraphicForm.LineManager.AddLineWithShadow(lowerLeft,
						new Point(lowerRight.X + 1, lowerRight.Y), col);

					// Draw connection line (makes more sense to understand structure)
					Point p1 =
						new Point(xPos + 20, previewRect.Y);
					Point p2 =
						new Point(xPos + 20, previewRect.Y - 8);
					Point p3 =
						new Point(xPos + 40 + 15, previewRect.Y - 8);
					Point p4 =
						new Point(xPos + 40 + 15, previewRect.Bottom);
					Point p5 =
						new Point(xPos + 40 + 30 + 20, previewRect.Bottom);
					Point p6 =
						new Point(xPos + 40 + 30 + 20, previewRect.Bottom - 8);
					col = Color.LightGray;
					GraphicForm.LineManager.AddLine(p1, p2, col);
					GraphicForm.LineManager.AddLine(p2, p3, col);
					GraphicForm.LineManager.AddLine(p3, p4, col);
					GraphicForm.LineManager.AddLine(p4, p5, col);
					GraphicForm.LineManager.AddLine(p5, p6, col);
				} // if
				else
				{
					// Show just one part
					level.Texture.RenderOnScreen(previewRect,
						new Rectangle(0, 0, 40, Math.Min(level.Length, 512)));

					// Draw lines around preview rect to mark highlighting
					Point upperLeft = new Point(previewRect.X, previewRect.Y);
					Point upperRight = new Point(previewRect.Right, previewRect.Y);
					Point lowerLeft = new Point(previewRect.X, previewRect.Bottom);
					Point lowerRight = new Point(previewRect.Right, previewRect.Bottom);
					GraphicForm.LineManager.AddLine(upperLeft, upperRight, col);
					GraphicForm.LineManager.AddLine(upperLeft, lowerLeft, col);
					GraphicForm.LineManager.AddLineWithShadow(upperRight, lowerRight,
						col);
					GraphicForm.LineManager.AddLineWithShadow(lowerLeft,
						new Point(lowerRight.X + 1, lowerRight.Y), col);
				} // else

				// Enable linear texture filtering again
				GraphicForm.EnableLinearTextureFiltering();

				// Level selected?
				if (form.MouseInBox(clickArea) &&
					quit == false &&
					(GameForm.Mouse.LeftButtonPressed &&
					form.wasMouseButtonPressedLastFrame == false ||
					XInput.AButton &&
					XInput.WasAButtonPressedLastFrame == false))
				{
					// Close mission selection
					form.RemoveCurrentGameScreen();

					// Remember selected level number for the sky rotation.
					Level.currentLevelNumber = num;

					// Start mission with this level
					form.AddGameScreen(new Mission(level, form.asteroidManager));
				} // if
			} // for (num)

			/*obs
			// Allow also selecting with XBox360 controller
			// Level selected?
			if ((XInput.AButton ||
				XInput.BButton ||
				XInput.XButton) &&
				quit == false)
			{
				// Close mission selection
				form.RemoveCurrentGameScreen();

				// Remember selected level number for the sky rotation.
				Level.currentLevelNumber =
					XInput.AButton ? 0 :
					XInput.BButton ? 1 : 2;
				Level level = form.levels[Level.currentLevelNumber];
				//obs: num;

				// Start mission with this level
				form.AddGameScreen(new Mission(level, form.asteroidManager));
			} // if
			 */
		} // Run(form)
		#endregion
	} // class MissionSelection
} // namespace RocketCommander.GameScreens
