// Project: Rocket Commander, File: ColorHelper.cs
// Namespace: RocketCommander.Graphics, Class: ColorHelper
// Path: C:\code\Rocket Commander\Graphics, Author: Abi
// Code lines: 123, Size of file: 1064 Bytes
// Creation date: 04.11.2005 05:01
// Last modified: 04.11.2005 05:03
// Generated with Commenter by abi.exDream.com

#region Using directives
using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using Microsoft.DirectX;
#endregion

namespace RocketCommander.Graphics
{
	/// <summary>
	/// Color helper, just to convert colors to different formats and providing
	/// more helper methods missing in the Color class.
	/// </summary>
	public class ColorHelper
	{
		#region Convert Color to Vector4
		/// <summary>
		/// Convert Color to Vector4
		/// </summary>
		/// <param name="color">Color</param>
		/// <returns>Return Vector4</returns>
		public static Vector4 ConvertColorToVector4(Color color)
		{
			return new Vector4(
				color.R / 255.0f,
				color.G / 255.0f,
				color.B / 255.0f,
				color.A / 255.0f);
		} // ConvertColorToVector4(col)
		#endregion

		#region Stay in range helper
		/// <summary>
		/// Stay in range, val will be set to min if less or to max when bigger.
		/// </summary>
		private static float StayInRange(float val, float min, float max)
		{
			if (val < min)
				return min;
			if (val > max)
				return max;
			return val;
		} // StayInRange(val, min, max)
		#endregion

		#region Multiply colors
		/// <summary>
		/// Multiply colors
		/// </summary>
		/// <param name="color1">Color 1</param>
		/// <param name="color2">Color 2</param>
		/// <returns>Return color</returns>
		public static Color MultiplyColors(Color color1, Color color2)
		{
			// Quick check if any of the colors is white,
			// multiplying won't do anything then.
			if (color1 == Color.White)
				return color2;
			if (color2 == Color.White)
				return color1;

			// Get values from color1
			float redValue1 = color1.R / 255.0f;
			float greenValue1 = color1.G / 255.0f;
			float blueValue1 = color1.B / 255.0f;
			float alphaValue1 = color1.A / 255.0f;

			// Get values from color2
			float redValue2 = color2.R / 255.0f;
			float greenValue2 = color2.G / 255.0f;
			float blueValue2 = color2.B / 255.0f;
			float alphaValue2 = color2.A / 255.0f;

			// Multiply everything using our floats
			return Color.FromArgb(
				(byte)(StayInRange(alphaValue1 * alphaValue2, 0, 1) * 255.0f),
				(byte)(StayInRange(redValue1 * redValue2, 0, 1) * 255.0f),
				(byte)(StayInRange(greenValue1 * greenValue2, 0, 1) * 255.0f),
				(byte)(StayInRange(blueValue1 * blueValue2, 0, 1) * 255.0f));
		} // MultiplyColors(color1, color2)
		#endregion

		#region Same color check
		/// <summary>
		/// Same color. Helper method for LoadLevel because for some reason
		/// the color compare does not work and causes a lot of errors.
		/// </summary>
		/// <param name="color">Color</param>
		/// <param name="checkColor">Check color</param>
		/// <returns>Bool</returns>
		public static bool SameColor(Color color, Color checkColor)
		{
			return color.R == checkColor.R &&
				color.G == checkColor.G &&
				color.B == checkColor.B;
		} // SameColor(color, checkColor)
		#endregion

		#region Interpolate color
		/// <summary>
		/// Interpolate color. Used to fade the hud colors from green to red.
		/// </summary>
		public static Color InterpolateColor(Color col1, Color col2, float percent)
		{
			return Color.FromArgb(
				(byte)((float)col1.A * (1.0f - percent) + (float)col2.A * percent),
				(byte)((float)col1.R * (1.0f - percent) + (float)col2.R * percent),
				(byte)((float)col1.G * (1.0f - percent) + (float)col2.G * percent),
				(byte)((float)col1.B * (1.0f - percent) + (float)col2.B * percent));
		} // InterpolateColor(col1, col2, percent)
		#endregion
	} // class ColorHelper
} // namespace RocketCommander.Graphics
