// Project: Rocket Commander, File: FormTests.cs
// Namespace: RocketCommander.Helpers, Class: TestForm
// Path: C:\code\Rocket Commander\Helpers, Author: Abi
// Code lines: 22, Size of file: 438 Bytes
// Creation date: 01.11.2005 18:46
// Last modified: 01.11.2005 19:06
// Generated with Commenter by abi.exDream.com

// Only required for unit tests in debug mode!
#if DEBUG
#region Using directives
using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using System.Windows.Forms;
#if DEBUG
using NUnit.Framework;
#endif
#endregion

namespace RocketCommander.Helpers
{
	/// <summary>
	/// Test form, used for sound and music unit tests.
	/// Can be extended and used for UI unit tests (easy buttons, etc).
	/// </summary>
	class TestForm : Form
	{
		#region Variables
		/// <summary>
		/// Control location
		/// </summary>
		private Point controlLocation;
		private bool quitApp = false;
		#endregion

		#region Constructor
		/// <summary>
		/// Create test form
		/// </summary>
		public TestForm()
		{
			base.Text = "Unit test form";
			base.Size = new Size(800, 600);
			controlLocation = new Point(4, 4);
		} // TestForm()

		/// <summary>
		/// Create test form
		/// </summary>
		/// <param name="titleName">Title name</param>
		public TestForm(string titleName)
			: this()
		{
			base.Text = titleName;
		} // TestForm(titleName)
		#endregion

		#region Add button
		/// <summary>
		/// Add button
		/// </summary>
		/// <param name="name">Name</param>
		/// <param name="buttonClick">Button click</param>
		public void AddButton(string name, EventHandler buttonClick)
		{
			Button newButton = new Button();
			newButton.Text = name;
			newButton.Location = controlLocation;
			newButton.Size = new Size(200, 26);
			controlLocation.Y += 30;
			newButton.Click += new EventHandler(buttonClick);
			this.Controls.Add(newButton);
		} // AddButton(name, buttonClick)
		#endregion

		#region Run
		/// <summary>
		/// Run
		/// </summary>
		public void Run()
		{
			WindowsHelper.ForceForegroundWindow(this);
			//old: Application.Run(this);
			this.Show();
			while (this.quitApp == false)
			{
				// Just update the game time
				ElapsedTime.Update();

				// And handle all default events
				Application.DoEvents();
			} // while (this.quitApp)
		} // Run()
		#endregion

		#region On closed
		protected override void OnClosed(EventArgs e)
		{
			quitApp = true;
			base.OnClosed(e);
		} // OnClosed(e)
		#endregion

		#region Unit Testing
#if DEBUG
		/// <summary>
 		/// Test test form
 		/// </summary>
 		[Test]
 		public static void TestTestForm()
 		{
			new TestForm("Test TestForm").Run();
 		} // TestTestForm()
#endif
		#endregion
	} // class TestForm
} // namespace RocketCommander.Helpers
#endif