#region Using directives
#if DEBUG
using NUnit.Framework;
#endif
using System;
using System.Collections.Generic;
using System.Text;
using RocketCommander.Graphics;
using Microsoft.DirectX.Direct3D;
using RocketCommander.Helpers;
using RocketCommander.Game;
using Texture = RocketCommander.Graphics.Texture;
using Microsoft.DirectX;
#endregion

namespace RocketCommander.Shaders
{
	class SimpleShader : IGraphicObject
	{
		#region Variables
		Effect effect = null;
		#endregion

		#region Constructor
		public SimpleShader()
		{
			effect = Effect.FromFile(GraphicForm.DirectXDevice,
				Directories.ShadersDirectory + "\\SimpleShader.fx",
				null, null, ShaderFlags.None, null);

			GraphicForm.AddGraphicObject(this);
		} // SimpleShader()
		#endregion

		#region IGraphicObject Member
		public void OnResetDevice()
		{
		}

		public void OnLostDevice()
		{
		}
		#endregion

		#region IDisposable Member
		public void Dispose()
		{
			if (effect != null)
				effect.Dispose();
		}
		#endregion

		#region Render mesh
		public void RenderMesh(Mesh someMesh, Texture texture)
		{
			GraphicForm.WorldMatrix =
				Matrix.Scaling(50, 50, 50);

			effect.SetValue("worldViewProj",
				GraphicForm.WorldMatrix *
				GraphicForm.ViewMatrix *
				GraphicForm.ProjectionMatrix);
			effect.SetValue("world",
				GraphicForm.WorldMatrix);
			effect.SetValue("viewInverse",
				GraphicForm.InverseViewMatrix);
			effect.SetValue("lightDir",
				new Vector4(
				GraphicForm.LightDir.X,
				GraphicForm.LightDir.Y,
				GraphicForm.LightDir.Z, 1.0f));
			effect.SetValue("diffuseTexture",
				texture.D3DTexture);

			effect.Technique = "SpecularPerPixel";

			int passes = effect.Begin(FX.None);
			for (int pass = 0; pass < passes; pass++)
			{
				effect.BeginPass(pass);
				someMesh.DrawSubset(0);
				effect.EndPass();
			} // for
			effect.End();
		} // RenderMesh(someMesh, texture)
		#endregion

		#region Unit Testing
#if DEBUG
		[Test]
		public static void TestSimpleShader()
		{
			SimpleShader shader = null;
			Mesh teapot = null;
			Texture testTexture = null;

			GameForm.StartTest("Test SimpleShader.fx",
				delegate
				{
					shader = new SimpleShader();
					teapot = Mesh.Teapot(GraphicForm.DirectXDevice);
					Model.GenerateNormalsAndTangentsIfNotPresent(ref teapot, false);
					testTexture = new Texture("Marble.jpg");
				},
				delegate
				{
					shader.RenderMesh(teapot, testTexture);
				});
		} // TestSimpleShader
#endif
		#endregion
	} // class SimpleShader
} // namespace RocketCommander.Shaders
