// Project: Rocket Commander, File: Sound.cs
// Namespace: RocketCommander.Sound, Class: Sound
// Creation date: 13.12.2004 03:28
// Last modified: 01.11.2005 18:44
// Generated with Commenter by abi.exDream.com

#region Using directives
using System;
using System.IO;
using System.Collections.Generic;
using Microsoft.DirectX;
using Microsoft.DirectX.DirectSound;
using DirectSound = Microsoft.DirectX.DirectSound;
using Buffer = Microsoft.DirectX.DirectSound.SecondaryBuffer;
using RocketCommander.Helpers;
using System.Windows.Forms;
#endregion

namespace RocketCommander.Sounds
{
	/// <summary>
	/// Sound will initialize DirectSound and manage all sound.
	/// </summary>
	public class Sound
	{
		#region Variables
		/// <summary>
		/// Sound device
		/// </summary>
		private static DirectSound.Device soundDevice = null;
		/// <summary>
		/// Get sound device for creating samples.
		/// </summary>
		internal static DirectSound.Device Device
		{
			get
			{
				return soundDevice;
			} // get
		} // Device

		/// <summary>
		/// Initialized
		/// </summary>
		private static bool initialized = false;
		/// <summary>
		/// Is DirectSound device initialized?
		/// </summary>
		public static bool Initialized
		{
			get
			{
				return initialized;
			} // get
		} // Initialized

		/// <summary>
		/// Remember all samples, we release them before disposing DirectSound.
		/// </summary>
		static List<Sample> allSamples = new List<Sample>();
		#endregion

		#region Initialization
		/// <summary>
		/// Create DirectSound device
		/// </summary>
		static public void Init(Form form)
		{
			if (initialized == true)
				return; // Already initialized

			try
			{
				soundDevice = new DirectSound.Device();
				soundDevice.SetCooperativeLevel(form, CooperativeLevel.Priority);
				initialized = true;
			} // try
			catch (Exception ex)
			{
				Log.Write("Could not create DirectSound device, " +
					"unable to play back any sound! Error: " + ex.ToString());
			} // catch (ex)
		} // Init(form)
		#endregion

		#region Add sample
		/// <summary>
		/// Add sample for disposing later, called from Sample constructor.
		/// </summary>
		/// <param name="sample">Sample</param>
		internal static void AddSample(Sample sample)
		{
			allSamples.Add(sample);
		} // AddSample(sample)
		#endregion

		#region Disposing
		/// <summary>
		/// Dispose DirectSound device
		/// </summary>
		static public void Dispose()
		{
			// Already disposed?
			if (initialized == false)
				return;

			try
			{
				// Kill all samples
				foreach (Sample sample in allSamples)
					sample.Dispose();

				// Kill sound device
				if (soundDevice != null)
					soundDevice.Dispose();
			} // try
			catch { } // ignore any error
			finally
			{
				initialized = false;
				soundDevice = null;
				allSamples.Clear();
			} // finally
		} // Dispose()

		/// <summary>
		/// Finalizer
		/// </summary>
		~Sound()
		{
			Dispose();
		} // ~Sound()
		#endregion
	}	// class Sound
} // namespace RocketCommander.Sounds
